# __MODULE_NAME__

This is a plugin for the [OVO ecosystem for de novo protein design](https://github.com/MSDLLCpapers/ovo).

TODO describe what the plugin does.

## Installation

To install the plugin, run:

```bash
pip install https://github.com/TODO_YOUR_REPO_NAME_HERE/__MODULE_NAME__
```
